@@ -170,6 +170,7 @@ OTC_SERVICES = {
     },
     'vpc': {
         'service_type': 'vpc',
+        'append_project_id': True,
     },
     'waf': {
         'service_type': 'waf',
@@ -268,7 +269,7 @@ def get_ak_sk(conn):
         return (None, None)
 
     else:
-        return(ak, sk)
+        return ak, sk
 
 
 def extend_instance(obj, cls):
