@@ -12,15 +12,139 @@
 from openstack import exceptions
 from openstack import proxy
 
+from otcextensions.sdk.vpc.v1 import bandwidth as _bandwidth
 from otcextensions.sdk.vpc.v1 import peering as _peering
 from otcextensions.sdk.vpc.v1 import route as _route
 from otcextensions.sdk.vpc.v1 import subnet as _subnet
 from otcextensions.sdk.vpc.v1 import vpc as _vpc
 
+from dataclasses import dataclass
+from typing import List
+
+
+@dataclass
+class PublicInfo:
+    publicip_id: str
+    publicip_type: str
+
 
 class Proxy(proxy.Proxy):
     skip_discovery = True
 
+    # ======== Bandwidth ========
+    def assign_bandwidth(self, **attrs):
+        """Assign bandwidth
+
+        :param dict attrs: Keyword arguments which will be used to assign
+            a :class:`~otcextensions.sdk.vpc.v1.bandwidth.Bandwidth`
+        """
+        project_id = self.get_project_id()
+        version = 'v2.0'
+        base_path = _bandwidth.Bandwidth.base_path % {'version': version,
+                                                      'project_id': project_id}
+        return self._create(_bandwidth.Bandwidth, project_id=project_id,
+                            base_path=base_path, **attrs)
+
+    def find_bandwidth(self, name_or_id, ignore_missing=False):
+        """Find a single bandwidth
+
+        :param name_or_id: The name or ID of a bandwidth
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised
+            when the vpc peering does not exist.
+            When set to ``True``, no exception will be set when attempting
+            to delete a nonexistent peering.
+
+        :returns: One :class:`~otcextensions.sdk.vpc.v1.bandwidth.Bandwidth`
+        """
+        project_id = self.get_project_id()
+        version = 'v1'
+        base_path = _bandwidth.Bandwidth.base_path % {'version': version,
+                                                      'project_id': project_id}
+        return self._find(
+            _bandwidth.Bandwidth, name_or_id,
+            project_id=project_id, base_path=base_path,
+            ignore_missing=ignore_missing)
+
+    def update_bandwidth(self, bandwidth, **attrs):
+        """Update a vpc peering
+
+        :param bandwidth: Either the ID of a vpc bandwidth or a
+                       :class:`~otcextensions.sdk.vpc.v1.bandwidth.Bandwidth`
+                       instance.
+        :param dict attrs: The attributes to update on the vpc bandwidth
+            represented by ``bandwidth``.
+
+        :returns: The updated bandwidth
+
+        :rtype: :class:`~otcextensions.sdk.vpc.v1.bandwidth.Bandwidth`
+        """
+        bandwidth = self._get_resource(_bandwidth.Bandwidth, bandwidth)
+        project_id = self.get_project_id()
+        version = 'v1'
+        return bandwidth.update_bandwidth(
+            self,
+            project_id,
+            version,
+            **attrs)
+
+    def add_eip_to_bandwidth(self, bandwidth, publicip_info: List[PublicInfo]):
+        """Add an EIP to a shared bandwidth.
+
+        :param bandwidth: The value can be the ID of a bandwidth
+           or a :class:`~otcextensions.sdk.vpc.v1.bandwidth.Bandwidth`
+           instance.
+        :param publicip_info: List of dictionaries in the format
+           {'publicip_id': id, 'publicip_type': type}
+        """
+        bandwidth = self._get_resource(_bandwidth.Bandwidth, bandwidth)
+        version = 'v2.0'
+        return bandwidth.add_eip_to_bandwidth(
+            self,
+            version,
+            publicip_info,
+            project_id=self.get_project_id())
+
+    def remove_eip_from_bandwidth(self, bandwidth, **attrs):
+        """Add an EIP to a shared bandwidth.
+
+        :param bandwidth: The value can be the ID of a bandwidth
+             or a :class:`~otcextensions.sdk.vpc.v1.bandwidth.Bandwidth`
+             instance.
+        :param attrs: Keyword arguments to remove eip: charge_mode, size,
+            publicip_info - array of eip in the format {'publicip_id': id}
+        """
+        bandwidth = self._get_resource(_bandwidth.Bandwidth, bandwidth)
+        project_id = self.get_project_id()
+        version = 'v2.0'
+        return bandwidth.remove_eip_from_bandwidth(
+            self,
+            project_id,
+            version,
+            **attrs)
+
+    def delete_bandwidth(self, bandwidth, ignore_missing=True):
+        """Delete a bandwidth
+
+        :param bandwidth: key id or an instance of
+            :class:`~otcextensions.sdk.vpc.v1.bandwidth.Bandwidth`
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the vpc peering does not exist.
+            When set to ``True``, no exception will be set when attempting to
+            delete a nonexistent peering.
+
+        :returns: ``None``
+        """
+        project_id = self.get_project_id()
+        version = 'v2.0'
+        base_path = _bandwidth.Bandwidth.base_path % {'version': version,
+                                                      'project_id': project_id}
+        return self._delete(
+            _bandwidth.Bandwidth, bandwidth,
+            ignore_missing=ignore_missing, project_id=project_id,
+            base_path=base_path)
+
     # ======== Peering ========
     def create_peering(self, **attrs):
         """Create a new vpc peering from attributes
