@@ -15,7 +15,10 @@ import uuid
 
 import mock
 
+from otcextensions.sdk.cbr.v3 import backup
+from otcextensions.sdk.cbr.v3 import checkpoint
 from otcextensions.sdk.cbr.v3 import policy
+from otcextensions.sdk.cbr.v3 import member
 from otcextensions.sdk.cbr.v3 import task
 from otcextensions.sdk.cbr.v3 import vault
 from otcextensions.tests.unit.osclient import test_base
@@ -84,6 +87,76 @@ class TestCBR(test_base.TestCommand):
         self.client = self.app.client_manager.cbr
 
 
+class FakeBackup(test_base.Fake):
+    """Fake one or more CBR backups"""
+
+    @classmethod
+    def generate(cls):
+        object_info = {
+            "id": 'id-' + uuid.uuid4().hex,
+            "name": 'name-' + uuid.uuid4().hex,
+            "checkpoint_id": 'id-' + uuid.uuid4().hex,
+            "created_at": uuid.uuid4().hex,
+            "description": uuid.uuid4().hex,
+            "expired_at": uuid.uuid4().hex,
+            "image_type": uuid.uuid4().hex,
+            "parent_id": uuid.uuid4().hex,
+            "project_id": uuid.uuid4().hex,
+            "protected_at": uuid.uuid4().hex,
+            "resource_az": uuid.uuid4().hex,
+            "resource_id": uuid.uuid4().hex,
+            "resource_name": 'resname' + uuid.uuid4().hex,
+            "resource_size": 5,
+            "resource_type": random.choice(['OS::Cinder::Volume',
+                                            'OS::Nova::Server']),
+            "status": 'available',
+            "updated_at": uuid.uuid4().hex,
+            "vault_id": uuid.uuid4().hex,
+            "provider_id": uuid.uuid4().hex,
+            "children": [{'id': 'child_backup_uuid_1'},
+                         {'id': 'child_backup_uuid_2'}]
+        }
+
+        obj = backup.Backup.existing(**object_info)
+        return obj
+
+
+class FakeCheckpoint(test_base.Fake):
+    """Fake one or more CBR checkpoint"""
+
+    @classmethod
+    def generate(cls):
+        object_info = {
+            'created_at': uuid.uuid4().hex,
+            'id': 'pid-' + uuid.uuid4().hex,
+            'status': 'available',
+            'name': 'checkpoint-' + uuid.uuid4().hex,
+            'vault':
+                {
+                    'id': uuid.uuid4().hex,
+                    'name': uuid.uuid4().hex,
+                    "resources": [
+                        {
+                            'name': 'resource-name-' + uuid.uuid4().hex,
+                            'resource_size': '6',
+                            'backup_size': '6840',
+                            'protect_status': 'available',
+                            'backup_count': '18',
+                            'type': 'OS::Nova::Server',
+                            'id': 'pid-' + uuid.uuid4().hex,
+                            'extra_info': '{}'
+                        }]
+            },
+            'extra_info':
+                {
+                    'name': 'backup-' + uuid.uuid4().hex
+            }
+        }
+
+        obj = checkpoint.Checkpoint.existing(**object_info)
+        return obj
+
+
 class FakePolicy(test_base.Fake):
     """Fake one or more CBR policies with random vaults list and patterns"""
 
@@ -163,6 +236,26 @@ class FakePolicyFixed(test_base.Fake):
         return obj
 
 
+class FakeMember(test_base.Fake):
+    """Fake one or more CBR members"""
+
+    @classmethod
+    def generate(cls):
+        object_info = {
+            "id": 'id-' + uuid.uuid4().hex,
+            "status": random.choice(['pending', 'accepted', 'rejected']),
+            "created_at": uuid.uuid4().hex,
+            "updated_at": uuid.uuid4().hex,
+            "backup_id": uuid.uuid4().hex,
+            "image_id": uuid.uuid4().hex,
+            "dest_project_id": uuid.uuid4().hex,
+            "vault_id": uuid.uuid4().hex
+        }
+
+        obj = member.Member.existing(**object_info)
+        return obj
+
+
 class FakeTask(test_base.Fake):
     """Fake one or more CBR task with random vaults list and patterns"""
 
