@@ -72,7 +72,7 @@ class TestVault(fakes.TestCBR):
             obj.billing.charging_mode,
             obj.billing.is_auto_pay,
             obj.billing.is_auto_renew,
-            obj.bind_rules.tags,
+            obj.bind_rules["tags"],
             obj.resources,
             obj.tags,
         )
@@ -110,7 +110,24 @@ class TestVault(fakes.TestCBR):
             ('value=val-tags, key=key-tags',)
         )
 
-        data, column = vault._add_tags_to_vault_obj(obj, data, column, 'tags')
+        data, column = vault._add_tags_to_vault_obj(obj, data, column)
+
+        self.assertEqual(data, verify_data)
+        self.assertEqual(column, verify_column)
+
+    def test_add_bind_rules_to_vault_output(self):
+        obj = fakes.FakeVault.create_one()
+
+        column = ()
+        data = ()
+        verify_column = (
+            'bind_rules',
+        )
+        verify_data = (
+            ('value=val-bind, key=key-bind',)
+        )
+
+        data, column = vault._add_bind_rules_to_vault_obj(obj, data, column)
 
         self.assertEqual(data, verify_data)
         self.assertEqual(column, verify_column)
@@ -348,14 +365,12 @@ class TestShowVault(fakes.TestCBR):
             self.object,
             self.data,
             self.columns,
-            'tags'
         )
 
-        self.data, self.columns = vault._add_tags_to_vault_obj(
+        self.data, self.columns = vault._add_bind_rules_to_vault_obj(
             self.object,
             self.data,
-            self.columns,
-            'bind_rules'
+            self.columns
         )
 
         self.assertEqual(self.columns, columns)
@@ -517,18 +532,16 @@ class TestCreateVault(fakes.TestCBR):
             self.columns
         )
 
-        self.data, self.columns = vault._add_tags_to_vault_obj(
+        self.data, self.columns = vault._add_bind_rules_to_vault_obj(
             self.object,
             self.data,
-            self.columns,
-            'bind_rules'
+            self.columns
         )
 
         self.data, self.columns = vault._add_tags_to_vault_obj(
             self.object,
             self.data,
-            self.columns,
-            'tags'
+            self.columns
         )
 
         self.assertEqual(self.columns, columns)
@@ -634,18 +647,16 @@ class TestUpdateVault(fakes.TestCBR):
             self.columns
         )
 
-        self.data, self.columns = vault._add_tags_to_vault_obj(
+        self.data, self.columns = vault._add_bind_rules_to_vault_obj(
             self.object,
             self.data,
-            self.columns,
-            'bind_rules'
+            self.columns
         )
 
         self.data, self.columns = vault._add_tags_to_vault_obj(
             self.object,
             self.data,
-            self.columns,
-            'tags'
+            self.columns
         )
 
         self.assertEqual(self.columns, columns)
