@@ -12,6 +12,7 @@
 from openstack.tests.unit import test_proxy_base
 
 from otcextensions.sdk.vpc.v1 import _proxy
+from otcextensions.sdk.vpc.v1 import bandwidth as _bandwidth
 from otcextensions.sdk.vpc.v1 import peering
 from otcextensions.sdk.vpc.v1 import route
 from otcextensions.sdk.vpc.v1 import subnet
@@ -24,6 +25,76 @@ class TestVpcProxy(test_proxy_base.TestProxyBase):
         self.proxy = _proxy.Proxy(self.session)
 
 
+class TestVPCBandwidth(TestVpcProxy):
+
+    def test_assign_bandwidth(self):
+        self.verify_create(self.proxy.assign_bandwidth, _bandwidth.Bandwidth,
+                           method_kwargs={'name': 'name'},
+                           expected_kwargs={
+                               'name': 'name',
+                               'project_id': self.proxy.get_project_id()
+                           })
+
+    def test_bandwidth_delete(self):
+        self.verify_delete(
+            self.proxy.delete_bandwidth, _bandwidth.Bandwidth, True,
+            mock_method='otcextensions.sdk.vpc.v1._proxy.Proxy._delete',
+            expected_kwargs={
+                'ignore_missing': True,
+                'project_id': self.proxy.get_project_id()
+            })
+
+    def test_add_eip_to_bandwidth(self):
+        bandwidth = _bandwidth.Bandwidth(id='id')
+        publicip_info = 'publicip_info'
+        version = 'v2.0'
+        self._verify(
+            'otcextensions.sdk.vpc.v1.bandwidth.Bandwidth.'
+            'add_eip_to_bandwidth',
+            self.proxy.add_eip_to_bandwidth,
+            method_args=[bandwidth, publicip_info],
+            expected_args=[self.proxy, version, publicip_info],
+            expected_kwargs={'project_id': self.proxy.get_project_id()}
+        )
+
+    def test_remove_eip_from_bandwidth(self):
+        bandwidth = _bandwidth.Bandwidth(id='id')
+        version = 'v2.0'
+        project_id = self.proxy.get_project_id()
+        self._verify(
+            'otcextensions.sdk.vpc.v1.bandwidth.Bandwidth.'
+            'remove_eip_from_bandwidth',
+            self.proxy.remove_eip_from_bandwidth,
+            method_args=[bandwidth],
+            expected_args=[self.proxy, project_id, version],
+            expected_kwargs={}
+        )
+
+    def test_update_bandwidth(self):
+        bandwidth = _bandwidth.Bandwidth(id='id')
+        version = 'v1'
+        project_id = self.proxy.get_project_id()
+        self._verify(
+            'otcextensions.sdk.vpc.v1.bandwidth.Bandwidth.update_bandwidth',
+            self.proxy.update_bandwidth,
+            method_args=[bandwidth],
+            expected_args=[self.proxy, project_id, version],
+            expected_kwargs={}
+        )
+
+    def test_find_bandwidth(self):
+        version = 'v1'
+        base_path = _bandwidth.Bandwidth.base_path % {
+            'version': version, 'project_id': self.proxy.get_project_id()}
+        self.verify_find(self.proxy.find_bandwidth, _bandwidth.Bandwidth,
+                         expected_args=[],
+                         expected_kwargs={
+                             'project_id': self.proxy.get_project_id(),
+                             'base_path': base_path,
+                             'ignore_missing': True
+                         })
+
+
 class TestVpcPeering(TestVpcProxy):
     def test_peering_create(self):
         self.verify_create(self.proxy.create_peering, peering.Peering,
